Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mapsme/omim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorvng <viktor.govako@gmail.com>2013-09-20 19:09:46 +0400
committerAlex Zolotarev <alex@maps.me>2015-09-23 02:02:06 +0300
commit6f2ad31c264c8209072df7cfed9e1027d8e3ee34 (patch)
treec5bc54c6931a6c559cb97d8d6e66af7285dda1e1 /indexer/feature_utils.hpp
parentf0122d60b5264645e2679220215c52a8a0083ce0 (diff)
[search] Correct zoom for result and fix balloon point for streets.
Diffstat (limited to 'indexer/feature_utils.hpp')
-rw-r--r--indexer/feature_utils.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/indexer/feature_utils.hpp b/indexer/feature_utils.hpp
index 0691682e9e..ab4ddc1c58 100644
--- a/indexer/feature_utils.hpp
+++ b/indexer/feature_utils.hpp
@@ -9,8 +9,8 @@ namespace feature
{
class TypesHolder;
- /// Get viewport to show given feature. Used in search.
- m2::RectD GetFeatureViewport(TypesHolder const & types, m2::RectD const & limRect);
+ /// Get viewport scale to show given feature. Used in search.
+ int GetFeatureViewportScale(TypesHolder const & types);
/// Get search rank for a feature.
/// Roughly, rank + 1 means that feature is 1.x times more popular.